Class: Flowlink::Product

Inherits:
ObjectBase show all
Defined in:
lib/flowlink_data/product.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ObjectBase

#fields, #to_hash

Class Method Details

.fieldsObject

This is an abstract class defining the standard product fields for Flowlink (and Wombat) as methods. It's intended use is as a super class for a specific distributor, where the methods take a hashable and return the value matching their namesake. These fields and their values are described here: https://support.wombat.co/hc/en-us/articles/202555810-Products



12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
# File 'lib/flowlink_data/product.rb', line 12

def self.fields
  [
    :id,
    :name,
    :sku,
    :description,
    :price,
    :cost_price,
    :available_on,
    :permalink,
    :meta_description,
    :meta_keywords,
    :shipping_category,
    :taxons,
    :options,
    :properties,
    :images,
    :variants
  ]
end

Instance Method Details

#available_onObject

Raises:

  • (NotImplementedError)


57
58
59
# File 'lib/flowlink_data/product.rb', line 57

def available_on
  raise NotImplementedError
end

#cost_priceObject

Raises:

  • (NotImplementedError)


53
54
55
# File 'lib/flowlink_data/product.rb', line 53

def cost_price
  raise NotImplementedError
end

#descriptionObject

Raises:

  • (NotImplementedError)


45
46
47
# File 'lib/flowlink_data/product.rb', line 45

def description
  raise NotImplementedError
end

#idObject

Raises:

  • (NotImplementedError)


33
34
35
# File 'lib/flowlink_data/product.rb', line 33

def id
  raise NotImplementedError
end

#imagesObject

Raises:

  • (NotImplementedError)


89
90
91
# File 'lib/flowlink_data/product.rb', line 89

def images
  raise NotImplementedError
end

#meta_descriptionObject

Raises:

  • (NotImplementedError)


65
66
67
# File 'lib/flowlink_data/product.rb', line 65

def meta_description
  raise NotImplementedError
end

#meta_keywordsObject

Raises:

  • (NotImplementedError)


69
70
71
# File 'lib/flowlink_data/product.rb', line 69

def meta_keywords
  raise NotImplementedError
end

#nameObject

Raises:

  • (NotImplementedError)


37
38
39
# File 'lib/flowlink_data/product.rb', line 37

def name
  raise NotImplementedError
end

#optionsObject

Raises:

  • (NotImplementedError)


81
82
83
# File 'lib/flowlink_data/product.rb', line 81

def options
  raise NotImplementedError
end

Raises:

  • (NotImplementedError)


61
62
63
# File 'lib/flowlink_data/product.rb', line 61

def permalink
  raise NotImplementedError
end

#priceObject

Raises:

  • (NotImplementedError)


49
50
51
# File 'lib/flowlink_data/product.rb', line 49

def price
  raise NotImplementedError
end

#propertiesObject

Raises:

  • (NotImplementedError)


85
86
87
# File 'lib/flowlink_data/product.rb', line 85

def properties
  raise NotImplementedError
end

#shipping_categoryObject

Raises:

  • (NotImplementedError)


73
74
75
# File 'lib/flowlink_data/product.rb', line 73

def shipping_category
  raise NotImplementedError
end

#skuObject

Raises:

  • (NotImplementedError)


41
42
43
# File 'lib/flowlink_data/product.rb', line 41

def sku
  raise NotImplementedError
end

#taxonsObject

Raises:

  • (NotImplementedError)


77
78
79
# File 'lib/flowlink_data/product.rb', line 77

def taxons
  raise NotImplementedError
end

#variantsObject

Raises:

  • (NotImplementedError)


93
94
95
# File 'lib/flowlink_data/product.rb', line 93

def variants
  raise NotImplementedError
end