Class: Flowlink::Product
- Inherits:
-
ObjectBase
- Object
- ObjectBase
- Flowlink::Product
- Defined in:
- lib/flowlink_data/product.rb
Class Method Summary collapse
-
.fields ⇒ Object
This is an abstract class defining the standard product fields for Flowlink (and Wombat) as methods.
Instance Method Summary collapse
- #available_on ⇒ Object
- #cost_price ⇒ Object
- #description ⇒ Object
- #id ⇒ Object
- #images ⇒ Object
- #meta_description ⇒ Object
- #meta_keywords ⇒ Object
- #name ⇒ Object
- #options ⇒ Object
- #permalink ⇒ Object
- #price ⇒ Object
- #properties ⇒ Object
- #shipping_category ⇒ Object
- #sku ⇒ Object
- #taxons ⇒ Object
- #variants ⇒ Object
Methods inherited from ObjectBase
Class Method Details
.fields ⇒ Object
This is an abstract class defining the standard product fields for Flowlink (and Wombat) as methods. It's intended use is as a super class for a specific distributor, where the methods take a hashable and return the value matching their namesake. These fields and their values are described here: https://support.wombat.co/hc/en-us/articles/202555810-Products
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 |
# File 'lib/flowlink_data/product.rb', line 12 def self.fields [ :id, :name, :sku, :description, :price, :cost_price, :available_on, :permalink, :meta_description, :meta_keywords, :shipping_category, :taxons, :options, :properties, :images, :variants ] end |
Instance Method Details
#available_on ⇒ Object
57 58 59 |
# File 'lib/flowlink_data/product.rb', line 57 def available_on raise NotImplementedError end |
#cost_price ⇒ Object
53 54 55 |
# File 'lib/flowlink_data/product.rb', line 53 def cost_price raise NotImplementedError end |
#description ⇒ Object
45 46 47 |
# File 'lib/flowlink_data/product.rb', line 45 def description raise NotImplementedError end |
#id ⇒ Object
33 34 35 |
# File 'lib/flowlink_data/product.rb', line 33 def id raise NotImplementedError end |
#images ⇒ Object
89 90 91 |
# File 'lib/flowlink_data/product.rb', line 89 def images raise NotImplementedError end |
#meta_description ⇒ Object
65 66 67 |
# File 'lib/flowlink_data/product.rb', line 65 def raise NotImplementedError end |
#meta_keywords ⇒ Object
69 70 71 |
# File 'lib/flowlink_data/product.rb', line 69 def raise NotImplementedError end |
#name ⇒ Object
37 38 39 |
# File 'lib/flowlink_data/product.rb', line 37 def name raise NotImplementedError end |
#options ⇒ Object
81 82 83 |
# File 'lib/flowlink_data/product.rb', line 81 def raise NotImplementedError end |
#permalink ⇒ Object
61 62 63 |
# File 'lib/flowlink_data/product.rb', line 61 def permalink raise NotImplementedError end |
#price ⇒ Object
49 50 51 |
# File 'lib/flowlink_data/product.rb', line 49 def price raise NotImplementedError end |
#properties ⇒ Object
85 86 87 |
# File 'lib/flowlink_data/product.rb', line 85 def properties raise NotImplementedError end |
#shipping_category ⇒ Object
73 74 75 |
# File 'lib/flowlink_data/product.rb', line 73 def shipping_category raise NotImplementedError end |
#sku ⇒ Object
41 42 43 |
# File 'lib/flowlink_data/product.rb', line 41 def sku raise NotImplementedError end |
#taxons ⇒ Object
77 78 79 |
# File 'lib/flowlink_data/product.rb', line 77 def taxons raise NotImplementedError end |
#variants ⇒ Object
93 94 95 |
# File 'lib/flowlink_data/product.rb', line 93 def variants raise NotImplementedError end |